@@ -30,6 +30,7 @@ function(behavior,phaseX,timeX,v1,v2){
   Means<-c(meanA,meanB) 
   
   
-  graphics.off()
+  
+  layout(rbind(1,2), heights=c(4,1))
   barplot(Means,ylab="mean",names.arg=c(v1,v2))
 }
